EWtoPy — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »

# EWtoPy

## Introduction

Ce programme convertit les données du format utilisé par le programme EasyWeather fourni avec la station météo, vers le format utilisé par pywws. Il est utile si vous avez utilisé EasyWeather pendant un certain temps avant de découvrir pywws.

Le fichier `EasyWeather.dat` n’est utilisé que pour fournir les données précédent le début des données pywws. Étant donné que votre station météo dispose de sa propre mémoire, vous devez exécuter LogData.py avant EWtoPy.py pour minimiser l’utilisation du fichier EasyWeather.dat.

EWtoPy.py convertit les horodates EasyWeather.dat de l’heure locale vers l’heure UTC. Cela peut causer des problèmes lorsque l’heure d’été se termine, puisque l’heure locale apparaît pour revenir en arrière d’une heure. Le programme tente de détecter et de corriger les horodates concernées, mais je n’ai pas pu tester cela sur une variété de fuseaux horaires.

## API détaillé

Convert EasyWeather.dat data to pywws format

    usage: python EWtoPy.py [options] EasyWeather_file data_dir
    options are:
     -h or --help    display this help
    EasyWeather_file is the input data file, e.g. EasyWeather.dat
    data_dir is the root directory of the weather data

Ce programme suppose que EasyWeather utilise votre heure locale et convertit les horodates en UTC. Cela peut créer des ambiguïtés lorsque les horloges reviennent à l’heure normale à l’automne; le programme tentant de détecter et de corriger l’heure.

Fonctions

`main`([argv]) |

`EWtoPy.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »